# passerelle - uniform access to multiple data sources and services
# Copyright (C) 2017 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import requests

from django.core.management.base import BaseCommand
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _

from ...models import GrandLyonStreetSections, StreetSection

class Command(BaseCommand):
    help = _('Retrieve list of Grand Lyon street sections')

    def handle(self, *args, **options):
        if not GrandLyonStreetSections.is_enabled():
            return
        if GrandLyonStreetSections.objects.count() == 0:
            return
        sections = requests.get(
                'https://download.data.grandlyon.com/ws/grandlyon/adr_voie_lieu.adraxevoie/all.json?maxfeatures=1000000').content
        update_start = timezone.now()
        for value in json.loads(sections).get('values'):
            section, created = StreetSection.objects.get_or_create(
                    codefuv=value.get('codefuv'),
                    codetroncon=value.get('codetroncon'))
            if value.get('nomcommune').startswith('LYON '):
                # remove districts from commune name
                value['nomcommune'] = 'LYON'
            for attribute in ('nom', 'nomcommune', 'domanialite'):
                setattr(section, attribute, value.get(attribute))
            for attribute in ('bornemindroite', 'bornemingauche',
                              'bornemaxdroite', 'bornemaxgauche',
                              'gid'):
                if value.get(attribute) == 'None':
                    if 'min' in attribute:
                        attribute_value = 0
                    elif 'max' in attribute:
                        attribute_value = 99999
                    else:
                        attribute_value = None
                else:
                    attribute_value = int(value.get(attribute))
                setattr(section, attribute, attribute_value)
            section.save()
        StreetSection.objects.filter(last_update__lt=update_start).delete()
